
# Your body will make itself heard       
#### By Alice Strete

# Introduction              

The way we eat and think of food today is bound to change. The increasing demand for food, especially meat and dairy, combined with the increasingly damaging effects of climate change on agriculture (Cho, 2018), will push the food industry to reconsider its methods, and consumers their choices. Within this context, technology companies, the new actors on the food industry stage, are suggesting a solution, one that disregards food as being archaic, inefficient, and the practices around food production and preparation as time-wasters. Their solution, materialized in consumer products dubbed as 'complete foods', is backed up by huge financial support from venture capital, and regarded as the future of food. With this in mind, the research developed within this thesis is based on the following question: is food on a path towards becoming obsolete?

Silicon Valley's interpretation of food does not reflect the importance people place on it. The focus within this culture is on profit-driven innovation, while the cultural role of food, gender representation, or collective values associated with sharing food, are largely unrepresented. Instead, the emphasis is on the continuous quest to improve food products, within the value system of techno-solutionism. This system revolves around striving for perfection, maximum efficiency, and zero ambiguity, all unrepresentative of food culture. Evgeny Morozov, in his book *To Save Everything, Click Here* critically describes this value system, explaining that "this never-ending quest to ameliorate [...] is shortsighted and only perfunctorily interested in the activity for which improvement is sought" (Morozov, 2013). Considering these aspects, food will become increasingly commodified and products such as meal replacements, the materialization of techno-solutionism in food, will continue to be pushed by venture capital-funded corporations as an universal response to anything from time management, nutritional dilemmas, food waste and sustainability.

Of course, it is imperative to rethink current ways of food production and consumption, from the harmful effects of industrial agriculture on the climate to the damage processed meals are causing our bodies. Issues such as food access and food waste also demand immediate action. However, the money currently being invested in food technologies are going into startup businesses selling hyper-processed complete foods, as well as gadgets and services that have consumers completely dependent on these companies for every meal, all while claiming to solve the problems listed above. Within this context, it will become increasingly easier for corporations to exploit the global food system and consumers, especially with food becoming more scarce on a global level.

Cooking is a task traditionally imposed on women, ever since the rise of agricultural societies, and continuing until today (Smith, 1997). The search for innovative solutions to improve the experience of eating and cooking has often been expressed throughout history, from the first iterations of food compressed inside a pill, an idea developed by both suffragettes and science-fiction enthusiasts, to various tools to make cooking easier and more efficient. Today, technology companies selling meal replacements and the services of gig workers claim to bring innovative solutions for the current zeitgeist, as well as a glimpse inside the future of food. At the same time, they completely disregard previous struggles that have led to these issues being discussed in the first place. Replacing the traditional role of women within the household with applications funded by venture capitalists does not contribute to reflecting on the value of these tasks, but instead further deems them as unworthy of one's time, within the framework of the post-mom economy.

To understand the way the the role of food is being transformed by technology companies, I follow a path through the history of cooking and gender roles in food preparation, the role technology has in food culture and the way Silicon Valley, an important actor in the world of technology, is appropriating food traditions and knowledge in creating new consumer products for the privileged. My research was inspired by the book *In the Age of the Smart Machine* by Shoshana Zuboff. In it, she described her privileged position to experience and investigate the world of labour on the verge of it being revolutionized by computerization (Zuboff, 1988). She looks at the changing relationship of workers to their own bodies, the abstraction of their work and the way this dramatic change influenced the relationships between individuals. It is fascinating to look at the meal replacement phenomenon, and the repositioning of food within society as potentially similar, while wondering what the future of food could look like in the context of ever increasing abstraction and commodification of food and the labour of cooking.

# Chapter 1 - The Gender on Your Plate

## We love food, we hate having to cook it

There is a theory of evolution that says the following: the development of the Homo Sapiens brain happened mainly due to the discovery of fire, and subsequently cooking. By using less energy to hunt for fresh food, and spending less time chewing raw materials, the human brain had increasingly more space and time to develop new activities, ponder upon its surroundings and grow in size (Wranghart, 2009). Throughout the years, cooking has maintained its crucial role worldwide, as a fundamental part of culture and society, but also as a way to make food safer to eat and easier to preserve. Cooking also represented a catalyst for humans to become more social beings, which became more civilized and introspective while sitting around the cooking fire (Pollan, 2014). But while everybody benefited from the positive aspects of cooked food, the labour associated with it became a task reserved only for some.

Women have been pushed towards domestic work ever since the evolution from more equal hunter-gatherer societies to settled agricultural societies (Smith, 1997). Traditionally, men provided the food, earned at first by hunting, and later on by going to their paid job. Women would be in charge of preparing food for everyone, and that role rarely changed. Throughout time, cooking as a means of caregiving became a practice identified more with women, while cooking as entertainment or skill display was, and still is, associated with men (Cairns et al. 2010). In many households it is still often considered a special occasion when the man of the house cooks. This view was reinforced in cooking advice from the 20th century; men do not cook on a daily basis, but when they do, they cook dishes that best display their skills (Vester, 2015).

Discussing the gender politics of cooking, Pollan wonders: "Was home cooking denigrated because the work was mostly done by women, or did women get stuck doing most of the cooking because our culture denigrated the work?"(Pollan, 2014). Men often had a privileged position when it comes to their cooking practice - mostly with meat, outdoors, seen as entertainment, celebrated as a display of skills, while women's cooking happened behind the closed kitchen doors. Today, most of the world-renowned chefs, the ones who win countless awards and get their own TV shows are men.

![](images/chefs.png)

However, the more time we spend watching chefs cook meals we'll never get to eat, the less time we spend cooking for ourselves. In the past decades, studies have shown that cooking time has declined (Pollan, 2014; Ferdman, 2015). Less cooking in the average household means, one the one side, less housework reserved for women. It also means that corporations have made great profits from providing the food we eat on a daily basis, which comes with several downfalls. Food made by a corporation has many more chemical ingredients, that people very rarely use in their kitchens (Pollan, 2014). Eating packaged foods has increased the distance between what raw ingredients are and where they come from, and the food we actually consume. "Food becomes just another commodity, an abstraction. And as soon as that happens we become easy prey for corporations selling synthetic versions of the real thing - what I call edible foodlike substances."(Pollan, 2014).


## Gender in the kitchen

The phrase *a woman's place is in the kitchen*, or in the home, has been traced back as far as Ancient Greece's Aeschylus. Since then, it has been restated and reinterpreted throughout history, in literature, art, and politics (Popik, 2013). We can see an example of this belief clearly phrased in a clip from *Leave it to Beaver*, a popular 50s American sitcom. In it, the father explains to a confused son why he's more suited to do all the grilling outdoors, while his mother works inside the kitchen. "A woman's place is in the home, and as long she's in the home, she might as well be in the kitchen. Women do alright when they have all the modern conveniences, but us men are better at this rugged type of outdoor cooking. Sort of a throwback to cavemen days." (Leave it to Beaver, 1957). His last remark reinforces the idea that gender roles have an evolutionary development, are part of human nature and should not be questioned.

A brilliant example of the portrayal of women in the kitchen, from a woman's perspective this time, is Martha Rosler's *Semiotics of the Kitchen*. In this performance piece, set in a typical kitchen, Martha Rosler manipulates kitchen tools with sudden, violent gestures, sometimes even performing useless tasks such as pretending to throw the contents of a spoon over her shoulder. Her piece is meant to express the frustration of women being stuck doing domestic labour, which is taken for granted. It is also a parody of the cooking shows of the time, particularly the one hosted by an always cheerful Julia Child. In her mock culinary show, she is no longer a cheerful performer, but uses the tools that have been assigned to her as an expression of anger and frustration: "when the woman speaks, she names her own oppression" (Rosler, 1975). Her piece shows that gender roles enforced traditionally within the household can be oppressive, especially when the labour of women is devalued and regarded as trivial.

![](images/martha.jpg)

As both men and women have been finding their place within the workforce, sharing the workload within the home has increased slightly. However, even in homes where both partners work full-time, the majority of chores and administrative tasks still fall on the woman's shoulders, either mentally, or in practice. The extra workload that consists of planning and organisation and leads to the execution of the tasks has been coined by feminists as *the mental load* (Emma, 2017). Household management is yet another invisible task done by women, a time-consuming work nonetheless, which adds up to the time already spent doing house chores.

Today, technology corporations offer us more options. Rather than sharing the work more equally, both the mental load and the actual chores can be automated, to some extent, through technological solutions. No longer framed explicitly as women's work, but continuing to be (de)valued as such, tasks such as cooking can be facilitated through various apps. From a tool of oppression directed at women, food becomes a task delegated to gig workers by startups and other corporations.

Regarding food as a tool of oppression has opened the way for many solutions, some more realistic than others. The automation of food and cooking has been a recurrent topic of conversation and space for imagination in both within social movements, and in popular culture.

## A meal in a pill

When the amount of chores one has to do as an adult takes up a considerable amount of time, it doesn't surprise me that most predictions about the future imagine ways in which technology will change the way we do things now. Early retrofuturist ideas depict future humans in flying cars, interacting with robots, or with superhuman abilities. They no longer waste time on daily tasks, since most things can be achieved with the press of a button. One aspect that keeps coming back, though, is the issue of food. No matter how advanced future humans will be, they will always have to eat, and the food has to be prepared by someone or something.

![](/home/alice/Documents/Thesis/images/All_work.jpg)

One of the first mentions of a solution to the division of labour in the kitchen came in a dystopian novella written in the late 19th century. The author was a conservative woman called  Anna Bowman Dodd, an avid critic of the women's emancipation movement. In *The Republic of the Future*, she imagines a transformed New York in the year 2050, governed by socialists and feminists, seen through the eyes of a Swedish aristocrat called Wolfgang. The man writes home to his friend and describes the life of future New Yorkers as joyless and bland. He blames the situation on a couple of developments such as equality between sexes, reduced labor hours and abolishing of class society.

In Dodd's work, food is provided not by kitchens, but personalized by scientists in the Office of Hygiene. In this future, food has been reduced to pellets or liquids transported to every home through pneumatic tubes, convenient enough to be taken in one's pocket and eaten on the go. The explanation for this development, that the author finds quite outrageous, is women's liberation. "If kitchens and cooking and long dinners hadn't been abolished, the final emancipation of women could never have been accomplished. [...] When the last pie was made into the first pellet, woman's true freedom began" (Dodd, 1887). Thus, the first idea of meal replacements as alternatives to time-consuming activities such as cooking appears, notably as a criticism, a ridiculous solution brought about by outrageous feminists who try to ruin everything that's fun in life.

Soon after, another futurist food reference was introduced. This came in Mary Lease's essay, a suffragette feminist from the late 19th century (Roodeburg, 2018). In her work, commissioned for World's Fair in Chicago in 1893, she envisioned the future of food 100 years from then. In her view, cooking was a chore that first wave feminists wanted to leave behind. Thus, in 1993, the future was supposed to look like this:

 "Science will take in condensed form from the rich loam of earth the life force or germs now found in the heart of the corn, the kernel of the wheat, the luscious juice of the fruits. A small phial of this life from the fertile bosom of mother earth will furnish man with subsistence for days, and thus the problems of cooks and cooking will be solved." (Lease in Novak, 2013)

The purpose of this futurist food was to liberate women from their household chores, and decrease inequality between both genders and social classes. It was also meant to provide a more sustainable food source, that would replace meat, and would make the lives of agricultural workers easier. In this imagined future, the labour of producing and preparing food is taken over by professionals, elevated to a scientific level, but still hidden from the eyes of the consumers.

Representations of food in the future are typically bleak. Regardless of it being a dystopian or utopian future, a drastic change in the way people consume food is called for. But one aspect of future food that is recurrent is the fact that food production is always obscured. There is no telling where the food behind the Food-a-Rac-a-Cycle in The Jetsons came from, nor what are the ingredients of the various meal-in-a-pill representations. However, when the origin of food is revealed, as with the examples in the movies *Soylent Green* and *The Snowpiercer*, it is usually a gruesome reality that is better to be obscured. This is yet another example of the work done inside kitchens of the past or the future being too confronting to be brought to light. The details of the actual cooking are either too boring or too disgusting to be revealed, when the only goal of food, as in the previous examples, is to fuel the human body.
![](images/snowpiercer.jpg)
![](images/soylent_green.jpg)

As mentioned in the previous examples, we can identify a number of attempts to improve the work situation of those who produce and prepare food. Throughout history, the work associated with food was recognized as being oppressive, and the suggested solutions involved either the need to make food obsolete, or to conceal the labour from the eyes of society. When cooking and the food itself are objects of mystery, their role is society is also heavily diminished.

## The value of time in the post-mom economy

The contemporary field of technology has created a world that suits its workers perfectly. A well-paid position in IT allows one to move from mom's home, which also means moving away from all the benefits that come with living under her roof. But the solution to all the extra work on their shoulders, which they are often unprepared or unwilling to do, can be easily fixed. Mother, in this situation, can be replaced with software tools - services performed via applications by gig workers.

In the *post-mom' economy* (Maney, 2015), there are services like Uber to drive you around, Washio to do your laundry, Deliveroo to bring your food, Lot 2046 to send you regular supplies of clothes and grooming items, Sleepscore to wake you up, and HydroCoach to remind you to drink water. These tasks, forms of unpaid labour traditionally reserved for the woman in the household, are deemed not worthy of one's already limited time, in a culture where people are being constantly pushed to always perform and be productive. Within the current economic regime, this workload is often performed by so-called *gig workers*, self-employed labourers controlled by applications, who work under the premise that they can manage their time however they want. Once mommy stopped providing these services, it's time for her to be replaced with an app.

The main goal of these services it to convince users to separate important decisions from meaningless ones, and focus their time on paid labour. Deciding how to dress and what to eat can be outsourced to a corporation, which uses this as its selling point. This form of convenient consumption limits the need to think about your choices, and becomes an automated form of comfort. Within this mindset, cooking is being presented as a chore rather than an activity that can be done as leisure. Entrepreneurs are encouraged, or rather pressured, to find solutions to problems they are facing themselves, and monetize every aspect of life. For many, the problem they face is becoming an adult with too much money to spend, and too little time outside of work. Keeping a high level of performance at work at all times does not allow much time and mind space for dealing with the practicalities of adult life, especially when they are framed as low-value, time consuming activities, and the latest consumer products reflect this reality.

![](images/speed.JPG)

The post-mom economy reflects embedded preconceptions on gender roles within the home. When the main provider of these services is not available, startups offer the option to replace her with a techno-solutionist product, that brings convenience for those who can afford it, while pushing others into low-wage gig work. Instead of reflecting on the value of maintaining a home and caregiving, or on the struggles of those who are pushed into these roles, the tasks are simply delegated to strangers. This further increases the infiltration of corporations into our lives under the pretense of earning more freedom (Pollan, 2014), while continuing to devalue *women's work*. Unless it is done for the purpose of entertainment, cooking is framed as an archaic chore, subjected to the specialization of labour, and awarded with a low wage.

![](images/freedom.png)

Technology has always had a massive importance in the world of food, and today we have numerous examples of new technologies that reflect our current socio-political climate. In the following chapter, I look at some of the ways in which the world of technology and the world of food are interconnected.

# Chapter 2 - Eating through algorithms

## Food as a tool for appropriation

The transfer of food terminology in programming, on a smaller scale, and the innovations in food technology on a larger scale are instances of cultural appropriation.

[^2]:"The unacknowledged or inappropriate adoption of the customs, practices, ideas, etc. of one people or society by members of another and typically more dominant people or society." (Oxford dictionary)

In the case of the current representations of food in society, a couple of examples where certain aspects of cultural appropriation are apparent are worthy of mention. In food technology, several products originally intended for women, or used traditionally by certain cultures, have been rebranded as innovations. One very famous example are weight loss meal replacement products such as Slimfast, turned into a product meant for busy, successful businessmen in the case of Soylent (Bowles, 2016). On the same note, cultural/spiritual traditions such as fasting (Tiku, 2016), doping with performance enhancement drugs (Bloomberg, 2016), or appropriated traditional recipes re-branded as proprietary innovations (Bulletproof, 2016) are all represented in Silicon Valley.
![](/home/alice/Documents/Thesis/images/idea.png)

A similar paradigm can be identified when it comes to computer lingo. I have not been able to find the starting point of the food terminology being used in the programming world, but my first introduction to it was through the O'Reilly cookbook collection. It seems that programmers are quite fond of this analogy, something that can be seen, for instance, in the foreword for the O'Reilly Perl Cookbook, written by Larry Wall. While, in his opinion, "Cooking is the humblest of arts", both cooking and programming languages can be used "not merely (for) getting the job done, but doing so in a way that makes your journey through life a little more pleasant" (Wall in Christiansen & Torkington, 1998). One of the nicest things he has to say within this analogy is the hope that Perl recipes will be passed on to future generations, much like traditional recipes written by grandmothers in old, dusty handwritten cookbooks.

![](/home/alice/Documents/Thesis/images/lrg.jpg)
![](/home/alice/Documents/Thesis/images/julia.JPG)

While the previous example is bound to give all programmers a warm and fuzzy feeling, there are plenty other less pleasant encounters with cooking analogies in the world of technology. On the one hand, there is a tendency to idealize the figure of the geek, the nerd, who prefers to hack away at his computer rather than face the real world. Portrayal of men (since the geek figure is always a man) as useless in the home, clumsy, inexperienced, only further reinforces the idea that it's the woman's role to stay on top of these domestic activities. Here's a telling example of this view, from a cookbook written specifically for this demographic:

  "Hackers, makers, programmers, engineers, nerds, techies—what we’ll call <geeks> for the rest of the book (deal with it)—we’re a creative lot who don’t like to be told what to do. We’d rather be handed a box full of toys or random electronic components [...]. But something happens to some geeks when handed a boxful of spatulas, whisks, and sugar. Lockup. Fear. Foreign feelings associated with public speaking, or worse, coulrophobia."(Potter, 2010)

[^1]: coulrophobia = Extreme or irrational fear of clowns. (Oxford Dictionaries)

On the other hand, there is the tendency to explain programming and algorithms using cooking as an analogy. This oversimplification is nothing new in terms of pedagogic methods, but in this case it makes the assumption that everyone is accustomed, familiar and comfortable with cooking, which is often not the truth. In addition to this, the analogy misrepresents cooking as an overly simple succession of tasks. In his book *Algorithmic Adventures. From Knowledge to Magic*, J. Hromkovic attempts for an entire chapter to find similarities between all aspects of an algorithm and cooking. The definition of the algorithm is meant to bridge the gap: "an algorithm [...] provides simple and unambiguous advice on how to proceed step by step in order to reach our goal." (Hromovic, 2009). However, throughout the rest of the chapter, I found the analogies more and more forced, making the entire explanation more confusing than it was intended. In another example, the author of a blog post is quick to note that "Programmers are the master chefs of the computing world - except the recipes they invent don't just give us a nice meal, they change the way we live"(Curzon, 2017). His claim seems to be: the two are similar, but, of course, cooking is infinitely more trivial than programming, because the latter has life-changing capacities.

The previous examples identify a pattern of appropriation within the field of technology, computer science in particular. This pattern applies to terminology, used derogatorily, as well as cultural artefacts, and is reflected in the techno-solutionist ideology associated with Silicon Valley. As I argue in the following sections, this phenomenon becomes materialized in the hyper-processed, reductionist food products generated by contemporary technology corporations, the production of which greatly resembles software or hardware, rather than food.

![](images/thinking.png)
# Disconnecting the mind from the body

## Socio-political context for the development of meal replacements

The rise of products branded as innovative foods has largely happened in the last decade, originating from Silicon Valley. The latest innovations, such as meal replacements, make promises for an empowered self, with full control over what one puts in one's body. Companies place a lot of emphasis on a scientific approach to selecting ingredients for a particular product, and brand their products as technologically advanced food items. But the process of producing or sourcing the ingredients is almost never exposed, thus further obscuring the processes involved in food production. One notable example is the company Huel, which created a video on YouTube titled *How Huel Is Made*, but failed to actually show their process. Instead, the video described its packaging and delivery system, a fact that was quickly noted in the comments section as disingenuous.

![](images/doorstep.png)

The celebration of not having time to tend to your bodily needs properly, and at the same time putting so much emphasis on giving the body personalized nutrition in the most pleasureless way is, of course, a paradoxical incongruity. At the same time, the idea that you are solely responsible for your well-being, and that you can control your health and efficiency with the right consumer habits is another heavily promoted concept. Trying to reconcile and adopt all these suggestions for how one should live their life is almost impossible, and leads to burnout. However, startups in Silicon Valley and all over the world are more than ready to provide products to any imaginable issue that can be identified, in order to achieve their prescribed quality of life. This is problematic in many ways, because it completely ignores other factors that influence our lives, such as social class, income, education, access etc, while promoting efficiency and production as the main goals to be achieved by humans.

## Nutrients > Food

Technology startups did not invent meal replacements, nor fortified foods. These products came on the market for various reasons historically, most importantly to deal with nutrient deficiencies. However, companies which produce meal replacements frame these products as ways to *disrupt mealtimes*. As expressed by Huel's community manager, "We wanted to strip it back to what the actual purpose of food is to provide nutrition (...) People are very focused on taste now – does it taste good? That is not the primary purpose of food"(Turk, 2018). Nutritionism and the food industry in general have, for decades, capitalized on people's fears and confusion related to food. They created the problem, and then promoted a product to allegedly solve it.

![](/home/alice/Documents/Thesis/images/vitamins1.jpg)
Today, companies which produce and sell meal replacements and other innovative food products put forward a number of health claims, including complete nutrition, better concentration, disease prevention, etc. But the lack of unaffiliated long-term scientific studies, and the association with nutritionists that sit on the board of directors are bound to raise suspicion. The fact that the food industry is able to make such claims can be traced back to the 90s, when the United States Congress passed a couple of laws, FDAMA (Food and Drug Administration Modernization Act) and DSHEA (Dietary Supplement Health and Education Act), which gave more freedom to the food and supplements industries to introduce new substances into their products without much pushback from the Food and Drug Administration (Nestle, 2013).

Looking at food as simply fuel for the body means completely disregarding the entire culture that has grown around food in every part of society. This phenomenon is described by Marion Nestle as reductionism, which, in this context, refers to reducing food to containers of nutrients. "Techno-foods offer a reductionist approach to choosing a healthful diet"(ibid) which only encourages food producers to come up with more and more products to sell to those who find this view appealing, or are confused regarding what foods are good for them. The above examples reveal that there there is a structural issue that has led to ultra-processed food products to appear on the market, under various health claims. This phenomenon is further exploited in the representation of what we perceive to be real food as an antiquated, and the push to promote processed products with a much higher market value, such as meal replacements.

## The rise of meal replacements

The way we transform nature for our personal purposes changes the way we relate to the world around us. This reductionist approach to food, as mentioned before, has led to the development of a new interpretation of food as fuel for the body. In this view, the cultural and social role of eating is trivialized, transforming one of the most significant aspects of society into a nuisance, an antiquated and inefficient way to maintain human life.

![](images/angle.png)

One telling example from today are complete foods, or meal replacements. Most commonly in the form of a powder meant to be mixed with water, these products allegedly contain all necessary nutrients, and can thus replace normal meals. Meal replacements target young professionals who can't find the time, or desire, to prepare and consume a traditional meal throughout the day, a situation many can relate to. By consuming a shake for breakfast and lunch, one does not have to sacrifice time, or nutritional value, in order to be able to keep going about their daily work. The companies producing these products, largely startups owned by technology entrepreneurs, promote them as solutions to a large variety of problems: lack of time, inconvenience of cooking, *food voids*, which is all the times one doesn't have direct access to a meal when hungry, world hunger, climate change, etc.

In my research of meal replacements I looked at the development of the brand Soylent, the first one of its kind. The product was developed in Silicon Valley by a couple of computer scientists. They were all young white males with no cooking experience, who were surviving on frozen fast food, and were frustrated by the quality of their meals and the time it took away from their day (Widdicombe, 2014). Taking the approach of an engineer in a social vacuum, they came to the conclusion that traditional nutrition is very inefficient. The best way to go about this, according to them, is by reducing food to its most basic elements. This comes across as the ultimate life hack, as it allows them to further release themselves from their bodily needs and exist purely for the purpose of being efficient in their search for profit. In this way, food preparation and consumption necessary on a daily basis is reduced to a minimum, and food is reinterpreted purely as fuel for the body.

![](home/alice/Documents/Thesis/images/soylent2-1.png)

After Soylent's astonishing success, and due to the fact that their product didn't meet international food regulation standards for shipping, many similar products appeared on the international market. Meal replacement brands are often promoted similarly to software or hardware, rather than food. They have different iterations, such as Soylent 1.0, 1.1, and so on, prominent lot numbers, and improvements are described as "fixing bugs" (Widdicombe, 2014). Framing them as products of technology pushes them further away from traditional food products, and further abstracts the role of food in our life.

The rise of meal replacements came not from a desire to improve food, but to disrupt the food industry and make the kind of profits a small technology startup can nowadays. The products are a techno-solutionist representation of Silicon Valley ideologies, manufacturing new problems in daily life that can only be fixed by them. They promote a quantified lifestyle, of an individual that is highly efficient and productive, both professionally and outside of work, to the point of burnout. And, going even further, they claim to improve people's health and solve food waste and world hunger, while disregarding issues such as wealth inequality and capitalist structures that have caused these problems in the first place. However, the products target a demographic similar to that of a technology startup, which is dominated by Western, middle and upper class individuals, which heavily limits the universal solution ideal that they promote.

Consuming your meals in the form of a complete food shake significantly reduces the time and energy spent on cooking and eating. This is meant to leave more time throughout the day for work, minimizing time-consuming lunch breaks at the office, profit loss and the workers' leisure time. Consuming food-like substances for the whole purpose of fueling your body also devalues the physical, psychological and social importance of food for humans, and disregards these crucial needs as trivial. This perspective on food furthers the disconnection between the working mind and the physiological needs of the body, promoting the value of one over the other.

# Chapter 3 - Becoming robots, losing our taste buds

## The future is already here — It's just not very evenly distributed (Gibson, Unknown)

Within the mainstream technology field, there is a current trend towards enhancing brain and physical capacities through consumer products. More specifically, disconnecting the weakness of the body from the sharpness of the mind can be identified in trends such as *meal disruption*, genomics, *the quantified self* and biohacking. These are also a result of the frustration of not being able to change some aspects of life, such as the need to eat, rest, and the inevitability of death. Within the small circles of the world's millionaires, these issues are of great interest, with fortunes invested into research and development.

In the view of Ray Kurzweil, the famous self-proclaimed futurist, the body deserves no respect in its fragility, and all its shortcomings can be conquered through the intelligence of the brain (Transcendent Man, 2009). In the future he predicts, a transhumanist future, the body as an unique physical entity has no place, when our minds will be able to explore many new worlds and inhabit virtual bodies, while holding vast amounts of universal knowledge.

In the same idea, and relating back to the topic discussed in the previous chapter, meal replacements represent an ideological universal solution to the problem of the body. In my view, they play the role of a consumer market-friendly product which comes as an introduction to bigger and more profitable issues, such as disease and aging. However, like universal knowledge, universal nutrition cannot represent a solution to the needs of the entire planet. The answers currently provided by companies which produce meal replacements are not as sustainable, affordable and appealing as they claim (Huel.com, 2017). Even though companies such as Soylent pride in collaborating with the World Food Program to provide meals for those in need, I believe that corporate solutions are not what the world needs to deal with its most pressing problems, such as climate change, poverty and access to food and water.

In recent years, more and more money and intelligence have been invested in Silicon Valley into studying the human body. The focus is not so much on curing diseases such as cancer and diabetes, but specifically on curing the one 'disease' affecting the upper classes: growing old. The richest of the rich are deeply invested in making themselves live as long as possible. The most likely implication of this plan is that anti-aging technologies will only be available to the elite, and will not benefit the rest of the world in any way.

Transhumanism represents "The belief or theory that the human race can evolve beyond its current physical and mental limitations, especially by means of science and technology" (Oxford dictionaries). Similarly, the practice of biohacking, non-traditional experimentation meant to improve the capacities of living organisms (Webster Dictionary), comes from the view that the body is simply another machine we can hack into. The aging body, with its physical needs, is a problem that current tech biohacking companies are trying to solve. This view is repeated over and over again by founders of various life-improving brain-enhancing death-repealing companies. At a health symposium in Los Angeles, Joon Yun, a doctor and hedge fund investor in longevity research announced: "I have the idea that aging is plastic, that it’s encoded [...] If something is encoded, you can crack the code. (...) If you can crack the code, you can hack the code!" (Friend, 2017).

Google has started a whole new secretive company, Calico, dedicated entirely to this purpose, considered "one of the first funders of transhumanism" (Fuck off Google wiki). As one of the major players in technology, Google Ventures has also become one of the main investors in life sciences, including food technology companies such as Soylent (Popper, 2013). This is one of the reasons why I feel that meal replacements represent just another piece in the puzzle, when it comes to technology innovations that hack the human body.

Since, according to transhumanism, the current state of the human body is at an early phase of development, there is still a lot of space for evolution. People who identify themselves as biohackers are experimenting with various ways of enhancing their awareness and brain function, as well as incorporating food innovations into their diets. For some, such as Mathijs Diederiks, from the YouTube channel futurefood, it is clear that traditional foods and ways of consuming them are part of an archaic diet. He described his view on futurist foods and their role in our lives in an interview, when asked about the portrayal of cooking and eating as a hassle:

![](images/futurefood.PNG)

 "M.D.: It makes total sense if you look at the current zeitgeist where everything is about optimization [...]. It echoes into everything we do. [...] That constant flux of presenting yourself, staying up to date, maintaining that ongoing energy, food has to find its place within that speed. That's what's happening in our society, everything is sped up. As humans, we haven't evolved in the last 15-20 years, we are still slow in terms of digestion... so I completely understand why these products are popular." (Strete and Diederiks, 2018)

But this enhanced future was never meant to be for everybody. Since there is no such thing as *trickle down transhumanism*, and these bio-technologies will most likely remain financially prohibitive for most of world's population, only very few will actually benefit from them.

 "While people of color, trans folks and the poor struggle to live within the timespan they’re allegedly already allotted [...], a handful of powerful white guys promote themselves as humanitarians for trying to extend the already long lives of the favored few. There aren’t many futures more chilling to me than one in which not even the march of time can free us from our oligarchs" (Shane, 2016). Even Bill Gates has recently warned the world that gene editing technology will only contribute to even greater inequality between the rich and the poor (Court, 2019).

Within this intense focus on the performance of the mind and the resilience of the body, there is immense pressure on individuals to keep up. Anything less than maximum efficiency feels unacceptable, and indulgences are frowned upon. Seeking pleasure and satisfaction in life is pushed to the very limited amount of *leisure time* one has these days outside of paid work. In fact, it is more appreciated if that time is spent instead in self-development activities such as exercising and tracking your progress, or following the advice of self-help books (Morozov, 2013). This constant pressure of being efficient can lead to extreme anxiety and burnout, which push human beings towards the dreaded low levels of efficiency they had before they started improving every part of their life.

Transhumanists predict a world where humans who can afford would be able to free themselves from their corporeal restraints and enhance their mental and physical abilities (McKie, 2018). They claim it's inevitable that changes in what we now think it means to be human are coming. However, the making, eating and sharing of food are inherent to human nature, and current representations of futurist food leave very little space for these activities. Within the transhumanist utopian dream, food becomes an afterthought, if considered at all. Indeed, one might wonder what kind of food can sustain these evolved bodies, what can be sufficient fuel to a mind that works beyond any current abilities? What is more, the reason behind the complete disregard for physical pleasure derived from food, in the context of elites with a wealth of technology at their disposal, is hard to grasp.

## The role of pleasure

In a world where the mind primes over the body, ingesting food for any other reason than sustenance does not seem to have a place. However great the attempts to develop neural networks that mimic the workings of the human brain, and to create anthropomorphic robots, a machine would still not be able to appreciate the joy, pleasure and complexity of a cooked meal. This idea is beautifully covered in Ellen Ullman's essay *Dining with Robots* where she imagines explaining to a robot the intricacies of cooking to a specific standard, the relation to a certain utensil to the food it's meant to be used for and the pleasure of sitting down and entertaining guests at a dinner party. She reflects on the incredible network of associations that people make when thinking of food: the name, the history, the origin, the memories, the feelings connected to it, and how one could explain all this to a machine.

But the real problem she identifies is pleasure, or the lack thereof. She asks: "Can a robot desire? Can it feel pleasure?". A system can be described as *happy* when it has everything it needs in order to function properly and efficiently. In the past century, especially in the Western world, humans have strived to overcome their limitations and become faster, more efficient, more machine-like. We've created machines to perform in ways we wish we could, and changed the world around us, including of food, to suit this vision better. Ullman looks around, inside a supermarket, surrounded by perfectly engineered produce and hygienic packaging and sighs: "Life is pressuring us to live by the robots’ pleasures[...]. Our appetites have given way to theirs. Robots aren’t becoming us [...]; we are becoming them" (Ullman, 2017).

### Low-tech solutions for the near future

An alternative to Silicon Valley's view of food hacking comes from a European group of hackers, who collaborate under the name Food Hacking Base. Their work focuses on food sustainability by using traditional preservation and food production methods to enhance the value of food, and to provide people with the necessary skills and understanding to reach a good level of self-sustainability.

In December 2018, I participated in the 35C3 conference in Leipzig to see their work. I was interested in their claim of combining traditional food making techniques with current advances in technology.
![](/home/alice/Documents/Thesis/images/probiotic.JPG)

From a kitchen open to everyone, they held workshops in various techniques, from kefir and tempeh making to probiotic drinks and beekeeping. They also added their hardware knowledge into the mix, by building their own devices, such as incubators for ferments. Their approach of providing people with skills and simple solutions like increasing the nutritional value of food and using few resources to produce sustainable food, as well as their collaborative, DIWO approach to cooking is quite valuable, and a beautiful alternative to mainstream techno-solutionism.

Today more than ever, with only over a decade to limit the disastrous effects of climate change, food alternatives are incredibly important. By the end of the century, global vegetable and legume production could fall by 35% due to water scarcity and other effects of climate change, and will have similar negative effects on livestock and seafood (Cho, 2018). These changes will inevitably increase inequality, with access to food and water becoming more scarce in certain parts of the world. Cooking, preservation and other low-tech skills could become crucial in dealing with food scarcity, as well as knowledge of local ingredients and techniques, since climate change will also have an effect on global food transportation (ibid). Communities focused on sharing skills and nutritional information freely and democratically have more value in times of need than corporations which target the upper classes, who already have increased access to resources.

# Conclusion

Food can represent a lifestyle statement, a source of pleasure, a stressful chore or a profitable business, and the new food industry actors, technology companies, are capitalizing on these representations. The labour of preparing food, and the importance placed on it has different meanings based on traditional gender roles and social class, and relates on individual perspectives regarding the value of one's time. With this in mind, my research on meal replacements becomes an analysis of a slice of society, viewed through the lens of food.

Technology has been crucial in making food easier to produce and distribute, but has also facilitated the production of an immense amount of processed foods. The food industry is thriving on the ambiguous nutritional information disseminated across the world, enabling the promotion of artificial foods as nutritionally superior. Meal replacements, the apex of processed foods available today, come from the highly competitive culture of mainstream, commercial technology from Silicon Valley. Within this culture, an entrepreneurial lifestyle in which making profit and being successful on all plans is promoted, which means significantly less time spent on mealtime breaks and cooking. It promotes specialization as a main principle, and nutritional reductionism as key.

The role food and cooking have played for centuries is seen as archaic and detrimental in the plan towards physical and mental enhancement, as practiced by biohackers and transhumanists. Meal replacements have little to no connection to traditional food, and take the role of fuel, rather than a pleasant source of nourishment and part of a cultural heritage. They represent a futurist dream of automation, ideologically underpinned by the secular religion of techno-solutionism, but the problems they claim to solve are just as manufactured.

In my research, I looked at potentially fundamental changes in the role of food, driven by societal and environmental pressures, as well as technological advances. Considering current forms of meal replacement products, I argued that they represent a stepping stone towards an increased abstraction of natural human habits and a techno-solutionist way of dealing with physical needs. Driven by Zuboff's research into the abstraction of labour through computerisation, I stressed the importance to reflect on the implications - social, political, environmental and cultural of the increasingly processed and reductionist forms of food promoted by Silicon Valley.

With accelerating levels of technological development, and increasingly destructive effects of climate change, the way we relate to the world is bound to change. In the next decades, these factors and others will greatly affect global food production. Some of the foods we are now used to eating will become harder to find and more expensive. Food is already becoming an even larger field of technological exploration and exploitation, with new ways of growing, producing, processing and distributing food being developed. Our options and preferences towards food will be even greatly influenced by technology companies, their products meaning to help us cope with these new circumstances, claiming to contribute to a better self in a better world, while catering only to the needs of the upper classes.

Increased life expectancy and health , something that Silicon Valley works hard towards, arguably only increases the need for nourishment. Our bodies will still need nutrition from good food. The importance of communities and organisations that dedicate their work towards a more fair distribution of food, skills and knowledge will grow, faced with increasing levels of inequality. At the end of the day, we will have to take matters into our own hands and learn how to prepare and preserve our food, and how to share the labour and the meals more equally amongst ourselves and with others.

# Appendix

### Manifesto

Based on Michael Pollan's eater's manifesto, Eat food. Not too much. Mostly plants., I'd like to add a couple more, however commonsensical they might seem. I encourage the reader to add more of her own.

* technology startups should not provide your food, and you should not eat it.

* read about food. Read labels, blog articles, news articles, cookbooks, history books, social sciences books. Chances are you'll find some new information about what you're eating, why you're eating it and where it came from.

* be critical of diets, food fads, miracle foods, complete foods, especially foods that are so overprocessed that you can't recognize their components anymore.

* use your kitchen, embrace failure. There is no better way to learn to make your own meals than to fail at it first.


# References

Anonymous (n.d.). In CS4F. Available at: http://www.cs4fn.org/programming/recipeprogramming.php

Cairns, K., Johnston, J., Baumann, S. (2010). Caring About Food: Doing Gender in the Foodie Kitchen. *Gender and Society*, Vol 24, pp 591–615.

de Certeau, M., Giard, L., Mayol, P. (1998). The Practice of Everyday Life, Volume 2: Living and Cooking. Minneapolis: University of Minnesota Press.

Cho, R. (2018). How Climate Change Will Alter Our Food. [blog] *State of the Earth* [online] Available at: https://blogs.ei.columbia.edu/2018/07/25/climate-change-food-agriculture/ [Accessed 15.02.2019]

Christiansen, T., Torkington, N. (1998). *Perl Cookbook*. Sebastopol, CA:O'Reilly

Court, E. (2019). Bill Gates warns that nobody is paying attention to gene editing, a new technology that could make inequality even worse. In *Business Insider* [online] Available at: https://www.businessinsider.nl/bill-gates-says-gene-editing-raises-ethical-questions-2019-1/?international=true&r=US [Accessed 10.01.2019]

Cultural Appropriation. (n.d.). In: *Oxford Dictionaries* [online] Oxford: Oxford University Press. Available at: https://en.oxforddictionaries.com/definition/cultural_appropriation [Accessed 07.12.2018]

Curzon, P. (2017). A Recipe for Programming. [blog] CS4FN [online] Available at: https://cs4fn.wordpress.com/2017/05/13/a-recipe-for-programming/ [Accessed 15.02.2019]

Dodd, A. (1887). *The Republic of the Future or Socialism a Reality*. New York: Cassel & Company ltd  

Dolejsova, M. (2016). Deciphering a Meal Through Open Source Standards: Soylent and the Rise of Diet Hackers. In: *alt.chi*. San Jose:CHI 2016.

Emma (2017). The gender wars of household chores: a feminist comic. *The Guardian*. [online] Available at: https://www.theguardian.com/world/2017/may/26/gender-wars-household-chores-comic [Accessed 29.01.2019]

Ferdman, R. (2015). The slow death of the home-cooked meal. In: *Washington Post*, [online] Available at: https://www.washingtonpost.com/news/wonk/wp/2015/03/05/the-slow-death-of-the-home-cooked-meal/?noredirect=on&utm_term=.ab16236b1588. [Accessed 22.01.2019]

Friend, T. (2017). Silicon Valley's Quest to Live Forever. *The New Yorker*, [online]. Available at: https://www.newyorker.com/magazine/2017/04/03/silicon-valleys-quest-to-live-forever [Accessed 28.11.2018]

Gibson, W. (unknown). The Future Has Arrived — It’s Just Not Evenly Distributed Yet [blog] Quote Investigator, [online] Available at: https://quoteinvestigator.com/2012/01/24/future-has-arrived/ [Accessed 04.03.2019]

Gowles, N. (2016). Food Tech Is Just Men Rebranding What Women Have Done for Decades. *The Guardian*, [online] Available at: https://www.theguardian.com/technology/2016/apr/01/food-technology-soylent-slimfast-juice-fasting [Accessed 05.12.2018]

Haraway, D. (1988). Situated Knowledges: The Science Question in Feminism and the Privilege of Partial
Perspective. *Feminist Studies*, Vol. 14(3), pp. 575-599

Hromovic, J. (2009). *Algorithmic Adventures. From Knowledge to Magic*. Berlin Heidelberg:Springer Verlag

Huel.com, (2017). *How Huel and the Huel Ingredients Are Produced*. [online] Available at: https://eu.huel.com/pages/how-huel-and-the-huel-ingredients-are-produced [Accessed 11.03.2019]

Juskalian, R. (2018). Inside the Jordan Refugee Camp that Runs on Blockchain. *MIT Technology Review*, [online] Available at: https://www.technologyreview.com/s/610806/inside-the-jordan-refugee-camp-that-runs-on-blockchain/ [Accessed 14.02.2019]

Kera, D., Denfeld, Z., Kramer, C. (2015). Food Hackers: Political and Metaphysical Gastronomes in the Hackerspaces. In: *Gastronomica*, Vol. 15(2), pp. 49-56

Leave it to the Beaver (1957). *Revue Studios*. [online] Available at: https://www.youtube.com/watch?v=MXhlTQJcgbc [Accessed 11.03.2019]

Maney, K. (2015). Silicon Valley Needs Moms! *Newsweek* [online] Available at: https://www.newsweek.com/2015/11/20/silicon-valley-working-replace-mothers-391794.html [Accessed 18.03.2019]

McKie, R. (2018). No Death and an Enhanced Life: Is the Future Transhuman? *The Guardian*, [online] Available at: https://www.theguardian.com/technology/2018/may/06/no-death-and-an-enhanced-life-is-the-future-transhuman [Accessed 06.02.2019]

Morozov, E. (2013). *To Save Everything, Click Here. The Folly of Technological Solutionism*. New York: Public Affairs.

Nestle, M. (2013). *Food Politics: How the Food Industry Influences Nutrition and Health, 3rd Edition*. Berkley: University of California Press

Novak, M. (2013). How Yesterday's Feminists Invented the Food of the Future. *Paleofuture Gizmodo*, [online] Available at: https://paleofuture.gizmodo.com/how-yesterdays-feminists-invented-the-food-of-the-futu-510350651 [Accessed 13.01.2019]

Pollan, M. (2008). *In Defense of Food. An Eater's Manifesto*. New York:Penguin Press

Popik, B. (2013) *A woman’s place is in the kitchen*.[Blog] The Big Apple. Available at: https://www.barrypopik.com/index.php/new_york_city/entry/a_womans_place_is_in_the_kitchen/ [Accessed 29.01.2019]

Popper, B. (2013). Understanding Calico: Larry Page, Google Ventures, and the Quest for Immortality. *The Verge* [online] Available at: https://www.theverge.com/2013/9/19/4748594/understanding-calico-larry-page-google-ventures-and-the-quest-for [Accessed 14.02.2019]

Potter, J. (2010). *Cooking for Geeks: Real Science, Great Hacks, and Good Food*. Sebastopol, CA: O'Reilly Media

Roodeburg, L. (2018). *Food Is Fiction*. Rotterdam:Nai010 Publishers

Rosler, M. (1975). *Semiotics of the Kitchen*

Shane, C. (2016). Life extension technology gives us a bleak future: more white men. *Splinternews*, [online] Available at: https://splinternews.com/life-extension-technology-gives-us-a-bleak-future-more-1793857274 [Accessed 06.12.2018]

Sharma, S. (2018). Going to Work in Mommy's Basement. *Boston Review*, [online] Available at: http://bostonreview.net/gender-sexuality/sarah-sharma-going-work-mommys-basement [Accessed 05.01.2019]

Smith, S. (1997). Engels and the Origin of Women's Oppression. In: *International Socialist Review*, Vol. 2

Strete, A. and Diederiks, M. (2018). Interview with futurefood.io

Tiku, N. (2016). Startup Workers Say No to Free Food, Hell Yeah to Intermittent Fasting. *Buzzfeed News*, [online] Available at: https://www.buzzfeednews.com/article/nitashatiku/intermittent-fasting [Accessed 05.12.2018]

*Transcendent Man*. (2009). [film] Unknown:Barry Ptolemy

Turk, V. (2018). Powdered Food is Back Again to Take on Sandwiches and Cereal. *Wired*, [online] Available at: https://www.wired.co.uk/article/huel-liquid-food-replacement-new-flavours [Accessed 05.12.2018]

Ullman, E. (2017). *Life in Code. A Personal History in Technology.* New York: Farrar, Strats and Giroux

Vester, K. (2015). *A Taste of Power: Food and American Identities*. Oakland: University of California Press.

Widdicombe, L. (2014). The End of Food. *The New Yorker* [online] Available at: https://www.newyorker.com/magazine/2014/05/12/the-end-of-food [Accessed 07.12.2018]

Woodcock, J. (2017). Subjectivity in the "Gig Economy": From the Entreprecariat to Base Union Militancy. *Pervasive Labour Union, Special Issue: The Entreprecariat* [online] Available at: http://ilu.servus.at/ilu_issue11.pdf [Accessed 13.02.2019]

Wortham, J. (2016). You, Only Better. *New York Times*, [online] Available at: https://www.nytimes.com/2015/11/15/magazine/you-only-better.html [Accessed 07.12.2018]

Zuboff, S. (1988). *In the Age of the Smart Machine*, Basic Books

#Image sources (need correct citation)

1. Top World Chefs, screenshot from Google search
2. Semiotics of the Kitchen
3. High Speed Meals
4. Regain Your Freedom, Feed
5. Wages for Housework, courtesy of Mayday Rooms
6. Snowpiercer Protein Bars
7. Soylent Green
8. Bulletproof Coffee
9. Want to Hack Your Body? Screenshot of YouTube video from Bloomberg
10. Python Cookbook
11. Mastering the Art of French Cooking
12. NerdShake 2.0
13. No Need to Think
14. How Huel is Made, screenshot of YouTube comment
15. Fortified Food
16. How to Eat Huel
17. Future Food, screenshot from Futurefood.io Instagram Story
18. Low-tech Probiotic Drinks, Food Hacking Base
